# Replication README

#### *Do parties matter for ethnic violence? Evidence from India*
#### Gareth Nellis, Michael Weaver, and Steven Rosenzweig
#### April 30, 2016

---

### Using this replication file

This file allows the user to reproduce any analysis referenced in the paper. In order to do this, users should take the following steps.

1. Open the main replication script file: [main.R](./main.R)
2. On line `23`, set the working directory as the folder containing the replication folder.
3. On line `26`, indicate whether you need to install the packages and their dependencies by setting `installPackages` to `TRUE` or `FALSE`. The default is `FALSE`. We suggest using this code to install the package versions used in the analysis. This code will take some time, as it loops through the list of packages until all are installed. **NOTE:** These packages are *source* files and must be compiled when they are installed. If you are using Windows or OS X, **you may not have the software required to compile the packages** from source. `installPackages.R` will attempt to install packages from source. If, after ten times through the installation loop,  any packages fail to compile, they will be installed from the package binaries available on [CRAN](https://cran.r-project.org/). If you want to ensure that you have the same exact package versions used in the analysis, you need to install the following software:
  * Windows: `RTools` can be obtained [here](https://cran.r-project.org/bin/windows/Rtools/)
  * OS X: Install `Xcode` from [here](https://developer.apple.com/xcode/). You will need to register (free) for an Apple Developer Connection account to download the application (not free).
  * Linux: There should be no problem installing from source.
4. On line `44`, indicate whether you want to make latex tables by setting `make.latex.tables` to `TRUE` or `FALSE`. The default is `TRUE`.
  * If you are running OSX, you will need to set `on.osx` to `TRUE`, on line `47` to successfully compile latex tables.
5. Before running any analyses you must first run lines `1` to `137` of `main.R`.
6. Each table and figure has its own eponymous script file contained in the [**scripts**](./scripts) folder. You can create specific tables and figures by either opening and running the corresponding script file, or using the corresponding `source` call in `main.R`.
7. To run the entire replication, you may run the entire `main.R` file.
8. `main.R` will produce a new [**output**](./output) folder and subfolders.
  * PDFs of figures will be saved to [**output/figures**](./output/figures).
  * TEX files for tables, if specified, will be saved to [**output/tables**](./output/tables).
  * CSV files containing simulation results for Figure D10 will be saved in [**output/simulations**](./output/simulations).

### Data files

1. [analysisPanelBW1.csv](./data/analysisPanelBW1.csv): District/election-cycle panel used in main analyses, where close elections are defined with a 1 percent bandwidth.
2. [analysisPanelBW2.csv](./data/analysisPanelBW2.csv): District/election-cycle panel used in main analyses, where close elections are defined with a 2 percent bandwidth.
3. [analysisPanelBW3.csv](./data/analysisPanelBW3.csv): District/election-cycle panel used in main analyses, where close elections are defined with a 3 percent bandwidth.
4. [closeElectionBalanceData.csv](./data/closeElectionBalanceData.csv): All state elections in India from 1960 to 2000, with election, constituency, and district level characteristics. Used for balance tests.
5. [districtNameCrosswalk.csv](./data/districtNameCrosswalk.csv): A file providing the names of districts corresponding to numeric IDs.
6. [muslimINCVoteshare.csv](./data/muslimINCVoteshare.csv): A file listing the overall and Muslim voteshare for the INC and the BJS/BJP. Data obtained from the Indian National Election Studies and polls reported by *India Today*. Used for Figure 1.
7. [muslimVoteshareByParty.csv](./data/muslimVoteshareByParty.csv): A file containing parties with the top three Muslim voteshares from several Indian National Election Studies and polls reported by *India Today*. Used for Figure D2.
8. [riotsByYear.csv](./data/riotsByYear.csv): A file containing the annual count of riots from *Varshney-Wilkinson Dataset on Hindu-Muslim Violence in India, 1950-1995* and the Mitra and Ray (2014) extension to 2000. Used for Figure D1.

### Replication File Contents

[**Root directory**](.)
  * [**data**](./data)
    * [analysisPanelBW1.csv](./data/analysisPanelBW1.csv)
    * [analysisPanelBW2.csv](./data/analysisPanelBW2.csv)
    * [analysisPanelBW3.csv](./data/analysisPanelBW3.csv)
    * [closeElectionBalanceData.csv](./data/closeElectionBalanceData.csv)
    * [districtNameCrosswalk.csv](./data/districtNameCrosswalk.csv)
    * [muslimINCVoteshare.csv](./data/muslimINCVoteshare.csv)
    * [muslimVoteshareByParty.csv](./data/muslimVoteshareByParty.csv)
    * [riotsByYear.csv](./data/riotsByYear.csv)
  * [main.R](./data/main.R)
  * [**output**](./output)
    * [**figures**](./output/figures)
    * [**simulations**](./output/simulations)
    * [**tables**](./output/tables)
  * [**packages**](./packages)
    * [acepack_1.3-3.3.tar.gz](./packages/acepack_1.3-3.3.tar.gz)
    * [AER_1.2-4.tar.gz](./packages/AER_1.2-4.tar.gz)
    * [bdsmatrix_1.3-2.tar.gz](./packages/bdsmatrix_1.3-2.tar.gz)
    * [beanplot_1.2.tar.gz](./packages/beanplot_1.2.tar.gz)
    * [car_2.1-2.tar.gz](./packages/car_2.1-2.tar.gz)
    * [chron_2.3-47.tar.gz](./packages/chron_2.3-47.tar.gz)
    * [cluster_2.0.3.tar.gz](./packages/cluster_2.0.3.tar.gz)
    * [codetools_0.2-14.tar.gz](./packages/codetools_0.2-14.tar.gz)
    * [colorspace_1.2-6.tar.gz](./packages/colorspace_1.2-6.tar.gz)
    * [data.table_1.9.6.tar.gz](./packages/data.table_1.9.6.tar.gz)
    * [dichromat_2.0-0.tar.gz](./packages/dichromat_2.0-0.tar.gz)
    * [digest_0.6.9.tar.gz](./packages/digest_0.6.9.tar.gz)
    * [doParallel_1.0.10.tar.gz](./packages/doParallel_1.0.10.tar.gz)
    * [foreach_1.4.3.tar.gz](./packages/foreach_1.4.3.tar.gz)
    * [foreign_0.8-66.tar.gz](./packages/foreign_0.8-66.tar.gz)
    * [Formula_1.2-1.tar.gz](./packages/Formula_1.2-1.tar.gz)
    * [ggplot2_2.1.0.tar.gz](./packages/ggplot2_2.1.0.tar.gz)
    * [gridExtra_2.2.1.tar.gz](./packages/gridExtra_2.2.1.tar.gz)
    * [gtable_0.2.0.tar.gz](./packages/gtable_0.2.0.tar.gz)
    * [Hmisc_3.17-3.tar.gz](./packages/Hmisc_3.17-3.tar.gz)
    * [iterators_1.0.8.tar.gz](./packages/iterators_1.0.8.tar.gz)
    * [labeling_0.3.tar.gz](./packages/labeling_0.3.tar.gz)
    * [lattice_0.20-33.tar.gz](./packages/lattice_0.20-33.tar.gz)
    * [latticeExtra_0.6-28.tar.gz](./packages/latticeExtra_0.6-28.tar.gz)
    * [lfe_2.5-1998.tar.gz](./packages/lfe_2.5-1998.tar.gz)
    * [lme4_1.1-12.tar.gz](./packages/lme4_1.1-12.tar.gz)
    * [lmtest_0.9-34.tar.gz](./packages/lmtest_0.9-34.tar.gz)
    * [magrittr_1.5.tar.gz](./packages/magrittr_1.5.tar.gz)
    * [MASS_7.3-45.tar.gz](./packages/MASS_7.3-45.tar.gz)
    * [Matrix_1.2-5.tar.gz](./packages/Matrix_1.2-5.tar.gz)
    * [MatrixModels_0.4-1.tar.gz](./packages/MatrixModels_0.4-1.tar.gz)
    * [minqa_1.2.4.tar.gz](./packages/minqa_1.2.4.tar.gz)
    * [munsell_0.4.3.tar.gz](./packages/munsell_0.4.3.tar.gz)
    * [nlme_3.1-127.tar.gz](./packages/nlme_3.1-127.tar.gz)
    * [nloptr_1.0.4.tar.gz](./packages/nloptr_1.0.4.tar.gz)
    * [nnet_7.3-12.tar.gz](./packages/nnet_7.3-12.tar.gz)
    * [pbkrtest_0.4-6.tar.gz](./packages/pbkrtest_0.4-6.tar.gz)
    * [plm_1.5-12.tar.gz](./packages/plm_1.5-12.tar.gz)
    * [plyr_1.8.3.tar.gz](./packages/plyr_1.8.3.tar.gz)
    * [quantreg_5.21.tar.gz](./packages/quantreg_5.21.tar.gz)
    * [RColorBrewer_1.1-2.tar.gz](./packages/RColorBrewer_1.1-2.tar.gz)
    * [Rcpp_0.12.4.tar.gz](./packages/Rcpp_0.12.4.tar.gz)
    * [reshape2_1.4.1.tar.gz](./packages/reshape2_1.4.1.tar.gz)
    * [rpart_4.1-10.tar.gz](./packages/rpart_4.1-10.tar.gz)
    * [sandwich_2.3-4.tar.gz](./packages/sandwich_2.3-4.tar.gz)
    * [scales_0.4.0.tar.gz](./packages/scales_0.4.0.tar.gz)
    * [SparseM_1.7.tar.gz](./packages/SparseM_1.7.tar.gz)
    * [stringi_1.0-1.tar.gz](./packages/stringi_1.0-1.tar.gz)
    * [stringr_1.0.0.tar.gz](./packages/stringr_1.0.0.tar.gz)
    * [survival_2.39-2.tar.gz](./packages/survival_2.39-2.tar.gz)
    * [tables_0.7.79.tar.gz](./packages/tables_0.7.79.tar.gz)
    * [xtable_1.8-2.tar.gz](./packages/xtable_1.8-2.tar.gz)
    * [zoo_1.7-12.tar.gz](./packages/zoo_1.7-12.tar.gz)
  * [ReadMe.md](./ReadMe.md)
  * [ReadMe.pdf](./ReadMe.pdf)
  * [**scripts**](./scripts)
    * [Figure1.R](./scripts/Figure1.R)
    * [Figure2.R](./scripts/Figure2.R)
    * [Figure3.R](./scripts/Figure3.R)
    * [Figure4.R](./scripts/Figure4.R)
    * [FigureA2_A3.R](./scripts/FigureA2_A3.R)
    * [FigureA4_A7.R](./scripts/FigureA4_A7.R)
    * [FigureA5_A6.R](./scripts/FigureA5_A6.R)
    * [FigureD1.R](./scripts/FigureD1.R)
    * [FigureD2.R](./scripts/FigureD2.R)
    * [FigureD3.R](./scripts/FigureD3.R)
    * [FigureD4.R](./scripts/FigureD4.R)
    * [FigureD5.R](./scripts/FigureD5.R)
    * [FigureD6.R](./scripts/FigureD6.R)
    * [FigureD7.R](./scripts/FigureD7.R)
    * [FigureD8_D9.R](./scripts/FigureD8_D9.R)
    * [FigureD10.R](./scripts/FigureD10.R)
    * [FigureD11.R](./scripts/FigureD11.R)
    * [FigureD12.R](./scripts/FigureD12.R)
    * [FigureD13.R](./scripts/FigureD13.R)
    * [installPackages.R](./scripts/installPackages.R)
    * [Table1.R](./scripts/Table1.R)
    * [TableA1.R](./scripts/TableA1.R)
    * [TableA2.R](./scripts/TableA2.R)
    * [TableD1.R](./scripts/TableD1.R)
    * [TableD2.R](./scripts/TableD2.R)
    * [TableD3.R](./scripts/TableD3.R)
    * [**functions**](./scripts/functions)
      * [bs.cluster.R](./scripts/functions/bs.cluster.R)
      * [ci.R](./scripts/functions/ci.R)
      * [cluster2.R](./scripts/functions/cluster2.R)
      * [Green_et_al_polanalysis_2009_edge.R](./scripts/functions/Green_et_al_polanalysis_2009_edge.R)
      * [Green_et_al_polanalysis_2009_optimal_bw.R](./scripts/functions/Green_et_al_polanalysis_2009_optimal_bw.R)
      * [mydotplot.R](./scripts/functions/mydotplot.R)


### Base Software Dependencies

1. `Ubuntu 14.04.4 LTS (Trusty Tahr) 64bit`
2. `R 3.2.5`

### Additional Software Dependencies

#### R packages

All packages were obtained from CRAN on April 24, 2016

Source files for required packages and their dependencies are contained in the replication file's [packages](./packages) folder.

1. [acepack 1.3-3.3](./packages/acepack_1.3-3.3.tar.gz)
* [AER 1.2-4](./packages/AER_1.2-4.tar.gz)
* [bdsmatrix 1.3-2](./packages/bdsmatrix_1.3-2.tar.gz)
* [beanplot 1.2](./packages/beanplot_1.2.tar.gz)
* [car 2.1-2](./packages/car_2.1-2.tar.gz)
* [chron 2.3-47](./packages/chron_2.3-47.tar.gz)
* [cluster 2.0.3](./packages/cluster_2.0.3.tar.gz)
* [codetools 0.2-14](./packages/codetools_0.2-14.tar.gz)
* [colorspace 1.2-6](./packages/colorspace_1.2-6.tar.gz)
* [data.table 1.9.6](./packages/data.table_1.9.6.tar.gz)
* [dichromat 2.0-0](./packages/dichromat_2.0-0.tar.gz)
* [digest 0.6.9](./packages/digest_0.6.9.tar.gz)
* [doParallel 1.0.10](./packages/doParallel_1.0.10.tar.gz)
* [foreach 1.4.3](./packages/foreach_1.4.3.tar.gz)
* [foreign 0.8-66](./packages/foreign_0.8-66.tar.gz)
* [Formula 1.2-1](./packages/Formula_1.2-1.tar.gz)
* [ggplot2 2.1.0](./packages/ggplot2_2.1.0.tar.gz)
* [gridExtra 2.2.1](./packages/gridExtra_2.2.1.tar.gz)
* [gtable 0.2.0](./packages/gtable_0.2.0.tar.gz)
* [Hmisc 3.17-3](./packages/Hmisc_3.17-3.tar.gz)
* [iterators 1.0.8](./packages/iterators_1.0.8.tar.gz)
* [labeling 0.3](./packages/labeling_0.3.tar.gz)
* [lattice 0.20-33](./packages/lattice_0.20-33.tar.gz)
* [latticeExtra 0.6-28](./packages/latticeExtra_0.6-28.tar.gz)
* [lfe 2.5-1998](./packages/lfe_2.5-1998.tar.gz)
* [lme4 1.1-12](./packages/lme4_1.1-12.tar.gz)
* [lmtest 0.9-34](./packages/lmtest_0.9-34.tar.gz)
* [magrittr 1.5](./packages/magrittr_1.5.tar.gz)
* [MASS 7.3-45](./packages/MASS_7.3-45.tar.gz)
* [Matrix 1.2-5](./packages/Matrix_1.2-5.tar.gz)
* [MatrixModels 0.4-1](./packages/MatrixModels_0.4-1.tar.gz)
* [minqa 1.2.4](./packages/minqa_1.2.4.tar.gz)
* [munsell 0.4.3](./packages/munsell_0.4.3.tar.gz)
* [nlme 3.1-127](./packages/nlme_3.1-127.tar.gz)
* [nloptr 1.0.4](./packages/nloptr_1.0.4.tar.gz)
* [nnet 7.3-12](./packages/nnet_7.3-12.tar.gz)
* [pbkrtest 0.4-6](./packages/pbkrtest_0.4-6.tar.gz) (Note: this package is only available for R versions 3.2.2 or newer.)
* [plm 1.5-12](./packages/plm_1.5-12.tar.gz)
* [plyr 1.8.3](./packages/plyr_1.8.3.tar.gz)
* [quantreg 5.21](./packages/quantreg_5.21.tar.gz)
* [RColorBrewer 1.1-2](./packages/RColorBrewer_1.1-2.tar.gz)
* [Rcpp 0.12.4](./packages/Rcpp_0.12.4.tar.gz)
* [reshape2 1.4.1](./packages/reshape2_1.4.1.tar.gz)
* [rpart 4.1-10](./packages/rpart_4.1-10.tar.gz)
* [sandwich 2.3-4](./packages/sandwich_2.3-4.tar.gz)
* [scales 0.4.0](./packages/scales_0.4.0.tar.gz)
* [SparseM 1.7](./packages/SparseM_1.7.tar.gz)
* [stringi 1.0-1](./packages/stringi_1.0-1.tar.gz)
* [stringr 1.0.0](./packages/stringr_1.0.0.tar.gz)
* [survival 2.39-2](./packages/survival_2.39-2.tar.gz)
* [tables 0.7.79](./packages/tables_0.7.79.tar.gz)
* [xtable 1.8-2](./packages/xtable_1.8-2.tar.gz)
* [zoo 1.7-12](./packages/zoo_1.7-12.tar.gz)

#### R functions

All functions can be found in the [**functions**](./scripts/functions/) folder.

1. `./scripts/functions/cluster2.R`: authors' function to calculate cluster robust standard errors.
2. `./scripts/functions/bs.cluster.R`: authors' function to calculate cluster bootstrap standard errors.
3. `./scripts/functions/ci.R`: authors' function to quickly calculate 95% confidence intervals.
4. `./scripts/functions/Green_et_al_polanalysis_2009_optimal_bw.R`: function from [(Green, et al. 2009)](http://isps.yale.edu/sites/default/files/publication/2012/12/ISPS09-023.pdf) to calculate optimal bandwidth for local linear regression discontinuity.
5. `./scripts/functions/Green_et_al_polanalysis_2009_edge.R`: function from [(Green, et al. 2009)](http://isps.yale.edu/sites/default/files/publication/2012/12/ISPS09-023.pdf) to estimate local linear regression discontinuity.
6. `./scripts/functions/mydotplot.R`: authors' function to create certain dotplots.

### Seed Locations

Figures D6 and D10 depend on bootstrapping to obtain standard errors. The seed for each bootstrap is set in the respective file: [FigureD6.R](./scripts/FigureD6.R) and [FigureD10.R](./scripts/FigureD10.R). The value of the seed used in both figures is set on line `92` of [main.R](./main.R).
