#################################
#################################
##Figure 4##
#################################
#################################

###########
#Load data#
###########
data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

#Create indicator for above median ENP
m = median(data$ENP, na.rm=T)
data$high_enp = NA
data$high_enp[!is.na(data$ENP)] = data$ENP[!is.na(data$ENP)] >= m

#Label subsets of the data
##########################
condition <- c("high_enp", "muslim_high")
condition.name <- c("High Party Fractionalization", "High Muslim Pop.")

#Set variable names for analysis
################################
#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Covariate
Cov <- paste(c("rd_INC_closeprop"), collapse="+")

#Generate plot data
###################
het.iv.plot.data <- data.frame(matrix(NA, nrow=2*length(condition)*length(log.riot.dvs), ncol=8))
names(het.iv.plot.data) <- c("DV", "Cond", "Value", "N", "Beta", "lower", "upper", 'p')
het.iv.plot.data$DV <- log.riot.dv.names 
het.iv.plot.data$Cond <- rep(condition.name, each=length(log.riot.dvs)*2)
het.iv.plot.data$Value <- rep(c("No","Yes"), each=length(log.riot.dvs))

#Loop over condition
####################
for (i in 1:length(condition)){	
  for (j in 0:1){
    index <- which(data[,condition[i]]==j)
    temp.subset <- data[index,]
    
    #Estimate instrumental variables model for each riot outcome
    out <- Map(function(y,w,x,z) ivreg(as.formula(paste(y,"~",paste(x,w,sep="+"),"|",paste(z,w,sep="+"))),data=temp.subset),log.riot.dvs,Cov,IV_end,IV_exo)
    
    #Obtain clustered standard errors for each model
    #Save results to table
    for (k in 1:length(log.riot.dvs)){
      est <- out[[k]]
      est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
      coef <- est.cl[2,1]
      se <- est.cl[2,2]
      upper <- coef + 1.96*se
      lower <- coef - 1.96*se
      p <- est.cl[2,4]
      
      plot.index <- k + length(log.riot.dvs)*j + 2*length(log.riot.dvs)*(i-1)
      het.iv.plot.data[plot.index,4:8] <- c(length(est$residuals), coef, lower, upper, p)
    }
  }
}


###################
#Generate Figure 4#
###################

plot.temp = het.iv.plot.data
plot.temp$Value[plot.temp $Value=="No"] = 1
plot.temp$Value[plot.temp$Value=="Yes"] = 2

plot.temp.1 = plot.temp[plot.temp$DV %in% c("Log Riot Count"),]
plot.temp.2 = plot.temp[plot.temp$DV %in% c("Pr(Any Riot)"),]


#Plot labels
y.scale <- list(y=list(at=2:1, labels= c("YES", "NO"), alternating=F), x=list(alternating=F))
y.label <- "Condition"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,2.5)

#X limits
x.limits.1 <- max(abs(plot.temp.1[,6:7])) * c(-1.05, 1.05)
x.limits.2 <- max(abs(plot.temp.2[,6:7])) * c(-1.05, 1.05)

#Size on page
width <- 6
height <- 6

#File name
name <- "Figure4"
file.name <- paste("./output/figures/",name,".pdf", sep="")

pdf(file.name, width=width, height=height)
dot.plot.1 <- Dotplot(Value ~ Cbind(Beta, lower, upper) | Cond + DV, data= plot.temp.1, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale=y.scale,  ylab=y.label, xlab=x.label, xlim=x.limits.1, ylim=y.limits,
                      panel = function(subscripts,...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")
                        #panel.text(2,.75,labels=paste("N = ",plot.temp.1$N[subscripts]), cex=.75)
                      })

dot.plot.2 <- Dotplot(Value ~ Cbind(Beta, lower, upper) | Cond + DV, data= plot.temp.2, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale=y.scale,  ylab=y.label, xlab=x.label, xlim=x.limits.2, ylim=y.limits,
                      panel = function(subscripts,...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")
                        #panel.text(.5,.75,labels=paste("N = ",plot.temp.2$N[subscripts]), cex=.75)
                      })

dot.plot = c(dot.plot.2, dot.plot.1)	
dot.plot$index.cond = list(c(1,2), c(1,2))
dot.plot$perm.cond= 1:2
dot.plot$condlevels = list(Cond = c("High Muslim Pop.", "High Party Fractionalization"), DV = c("Any Riot", "Log Riot Count"))
print(dot.plot)

dev.off()	

#Print table used for chart
cat("\n")
print("Figure 4")
print(plot.temp)
cat('\n')


#############################################################
#Alternate variable specification, mentioned in footnote (?)#
#############################################################
#Low muslim areas may have less suppression of riots by the INC, 
#because there are simply fewer opportunities for riots to occur. 
#We account for this by replicating our analyses, 
#using new riot variables that are constructed by taking the residuals 
#of regression current riot outcomes on lagged riot outcomes. 
#This way, we examine the effect of INC on riots that cannot be 
#explained by district propensity for violence.

#Calculate residuals of current riot count regressed on lagged riot count
# suppressWarnings(est <- glm.nb(COUNT ~ COUNT_1ec, data))
# residuals = est$residuals
# index = names(residuals)
# data[index,"COUNT.r"] = residuals
# data$log.COUNT.r = log(data$COUNT.r + 1.01)
# 
# #Calculate residuals of any riots regressed on lagged any riots
# est <- glm(COUNT.bin ~ COUNT_1ec > 0, data, family=binomial(link='probit'))
# data$COUNT.bin.r = as.numeric(data$COUNT.bin - predict(est, data, type='response') )
# 
# ################################################
# #Replicate Muslim tests using residual violence#
# ################################################
# #Any riots, low Muslim
# est = ivreg(COUNT.bin.r ~ rd_INC_seatprop + rd_INC_closeprop | rd_INC_iv + rd_INC_closeprop, data=data[data$muslim_high==0,])
# coeftest.cluster(data[data$muslim_high==0,], est, cluster1="DISTRICT_ID_61")
# 
# #Any riots, High Muslim
# est = ivreg(COUNT.bin.r ~ rd_INC_seatprop + rd_INC_closeprop | rd_INC_iv + rd_INC_closeprop, data=data[data$muslim_high==1,])
# coeftest.cluster(data[data$muslim_high==1,], est, cluster1="DISTRICT_ID_61")
# 
# #Riot Count, low Muslim
# est = ivreg(log.COUNT.r ~ rd_INC_seatprop + rd_INC_closeprop | rd_INC_iv + rd_INC_closeprop, data=data[data$muslim_high==0,])
# coeftest.cluster(data[data$muslim_high==0,], est, cluster1="DISTRICT_ID_61")
# 
# #Riot Count, High Muslim
# est = ivreg(log.COUNT.r ~ rd_INC_seatprop + rd_INC_closeprop | rd_INC_iv + rd_INC_closeprop, data=data[data$muslim_high==1,])
# coeftest.cluster(data[data$muslim_high==1,], est, cluster1="DISTRICT_ID_61")
