#######################
#######################
##Figures A4 and A7####
#######################
#######################


#Select pre-treatment variables
dvs.to.lag = c(riot.dvs, "rd_INC_seatprop", "INC_voteshare")

#Names of pre-treatment variables
lagged.dvs <- paste(dvs.to.lag, "_1ec", sep="")

#Labels for pre-treatment variables 
lagged.dv.names = paste("Lagged", c(riot.dv.names, "INC Seat %", "INC District Voteshare"))

#Endogenous treatment
IV_end <- "rd_INC_seatprop"
#Exogenous treatment
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("saturated"), collapse="+")


#Generate Plot Data
###################
random.plot.data <- data.frame(matrix(NA, nrow=length(lagged.dvs)*3, ncol=7))
names(random.plot.data) <- c("IV", "BW", "N", "Beta", "lower", "upper", "IV.num")
random.plot.data$IV <- lagged.dv.names
random.plot.data$BW <- rep(1:3, each=length(lagged.dvs))
random.plot.data$IV.num = 1:length(lagged.dvs)

for (i in 1:3){
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  
  #Lag Riot Variables
  varlist <- lagged.dvs
  
  #Scale pre-treatment variables
  for (var in varlist){	
    temp.data[,c(var)] <- scale(as.vector(temp.data[,c(var)]))
  }
  
  #Estimate effect of pre-treatment variables on instrument
  out <- Map(function(y,w,z) lm(as.formula(paste(z,"~",paste(y,w,sep="+"))),data= temp.data), lagged.dvs, Cov,IV_exo)
  
  #Loop over pre-treatment variables to get clustered SEs
  for (j in 1:length(dvs.to.lag)){
    est <- out[[j]]
    est.cl <- coeftest.cluster(temp.data, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    
    random.plot.data[(i-1)*length(lagged.dvs) + j ,3:6] <- c(length(est$residuals), coef, lower, upper)
  }
  rm(temp.data);gc()
}	


####################
#Generate Figure A4#
####################

#Randomization checks for violence at all bandwidths

#Plot labels
y.scale <- list(y=list(at=1:3, labels=paste(1:3,"%",sep=""), alternating=F))
y.label <- "Bandwidth"
x.label <- expression(paste(hat(beta),": Effect of Previous Violence (normalized)"))
y.limits <- c(.5,3.5)

#Size on page
width <- 6
height <- 5

#Select data for plot
data.for.plots <- list(random.plot.data[random.plot.data$IV %in% c("Lagged Riot Count", "Lagged Any Riot"), ])
names(data.for.plots) <- "FigureA4"

plot.temp <- data.for.plots[[1]]
name <- names(data.for.plots)[1]
file.name <- paste("./output/figures/",name,".pdf", sep="")

#Plot parameters
x.limits <- max(abs(plot.temp[,5:6])) * c(-1.05, 1.05)

pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(BW ~ Cbind(Beta, lower, upper) | IV, data=plot.temp, strip.blank=T, col=1,layout=c(1,2), par.settings=my.theme, cex=1.1, scales=y.scale, ylab=y.label, xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")})
print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure A4")
print(plot.temp)
cat('\n')

####################
#Generate Figure A7#
####################

#Randomization checks for pre-treatment variables at 1% bandwidth

#Plot labels
y.scale <- list(y=list(at=1:4, labels=lagged.dv.names[c(1,4:6)], alternating=F))
y.label <- "Pre-treatment Variables"
x.label <- expression(paste(hat(beta),": Effect of Pre-treatment Variables (normalized)"))
y.limits <- c(.5,4.5)

#Size on page
width <- 6
height <- 5

#We plot lagged riot count, lagged any riot, lagged INC seat share, lagged INC voteshare
plot.pre.treat = lagged.dv.names[c(1,4:6)]

#Select data for plot
data.for.plots <- list(random.plot.data[random.plot.data$IV %in% plot.pre.treat & random.plot.data$BW==1,])
data.for.plots[[1]]$IV.num = 1:4
names(data.for.plots) <- "FigureA7"
plot.temp <- data.for.plots[[1]]
name <- names(data.for.plots)[1]
file.name <- paste("./output/figures/",name,".pdf", sep="")

#Plot parameters
x.limits <- max(abs(plot.temp[,5:6])) * c(-1.05, 1.05)

pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(IV.num ~ Cbind(Beta, lower, upper), data=plot.temp, strip.blank=T, col=1,layout=c(1,1), par.settings=my.theme, cex=1.1, scales=y.scale, ylab=y.label, xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")})
print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure A7")
print(plot.temp)
cat('\n')


