#####################
#####################
##Figures A5 and A6##
#####################
#####################

#Select pre-treatment variables
placebo.dvs = c(log.riot.dvs)

#Names of pre-treatment variables
placebo.dvs <- paste(placebo.dvs, "_1ec", sep="")

#Labels for pre-treatment variables 
placebo.dv.names = c(log.riot.dv.names)


#######################
#Figure A5: Using IVLS#
#######################

#Endogenous treatment
IV_end <- "rd_INC_seatprop"
#Exogenous treatment
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("saturated"), collapse="+")

####################
#Generate plot data#
####################

placebo.iv.plot.data <- data.frame(matrix(NA, nrow=3*length(placebo.dvs), ncol=6))
names(placebo.iv.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "DV.num")
placebo.iv.plot.data$DV <- rep(placebo.dv.names, 3)
placebo.iv.plot.data$BW <- rep(1:3, each=length(placebo.dvs))
placebo.iv.plot.data$DV.num <- 1:length(placebo.dvs)


#Estimates for 3,2,1% bandwidths
for (i in 1:3){
  #Load data for bandwidth
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  
  #Log lagged riot dvs
  for (var in riot.dvs[riot.dvs != 'COUNT.bin']){
    lagged.var = paste0(var, "_1ec")
    new.var = paste0('log.', lagged.var)
    temp.subset[, new.var] = log(temp.subset[,c(lagged.var)] + .01)
  }

  #Estimate placebo tests: effect of treatment on pre-treatment outcomes.
  out <- Map(function(y,w,x,z) ivreg(as.formula(paste(y,"~",paste(x,w,sep="+"),"|",paste(z,w,sep="+"))),data=temp.subset),placebo.dvs,Cov,IV_end,IV_exo)
  
  #Obtain clustered standard errors
  for (j in 1:length(placebo.dvs)){
    est <- out[[j]]
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    
    #Save parameters for plotting
    placebo.iv.plot.data[j + length(placebo.dvs)*(i-1),3:5] <- c(coef, lower, upper)
  }
  rm(temp.subset)
}

####################
#Generate Figure A5#
####################

#Select data for plot
plot.data = placebo.iv.plot.data[placebo.iv.plot.data$DV %in% c("Log Riot Count", "Pr(Any Riot)"),]

#Plot labels
y.scale <- list(y=list(at=1:3, labels=paste(1:3,"%",sep=""), alternating=F))
y.label <- "Bandwidth"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,3.5)

#Size on page
width <- 6
height <- 5

#File name
plot.temp <- plot.data
name <- "FigureA5"
file.name <- paste("./output/figures/",name,".pdf", sep="")

x.limits <- max(abs(plot.temp[,4:5])) * c(-1.05, 1.05)

pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(BW ~ Cbind(Beta, lower, upper) | DV, data=plot.temp, strip.blank=T, 
                    col=1,layout=c(1,2), par.settings=my.theme, cex=1.1, scales=y.scale, 
                    ylab=y.label, xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")})
print(dot.plot)
dev.off()


#Print table used for chart
cat("\n")
print("Figure A5")
print(plot.temp)
cat('\n')

############
#Figure A6:#
############

#Select pre-treatment variables
placebo.dvs = c(riot.dvs)

#Names of pre-treatment variables
placebo.dvs <- paste(placebo.dvs, "_1ec", sep="")

#Labels for pre-treatment variables 
placebo.dv.names = c(riot.dv.names)


#Endogenous treatment
IV_end <- "rd_INC_seatprop"
#Exogenous treatment
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("saturated"), collapse="+")

#Generate plot data
placebo.nb.plot.data <- data.frame(matrix(NA, nrow=3*length(riot.dvs), ncol=5))
names(placebo.nb.plot.data) <- c("DV", "BW", "Beta", "lower", "upper")
placebo.nb.plot.data$DV <- rep(riot.dv.names, 3)
placebo.nb.plot.data$BW <- rep(1:3, each=length(riot.dvs))

#Estimate across bandwidths
for (i in 1:3){
  #Load data
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  
  #Estimate negative binomial for count data; estimate probit for "Any Riots"
  out <- Map(function(y,w,z) 
    if (length(unique(na.omit(temp.subset[,y])))==2){
      glm(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset, family=binomial(link="probit"))	
    }
    else {
      glm.nb(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset)
    }, placebo.dvs,Cov,IV_exo)
  
  #Obtain clustered standard errors
  for (j in 1:length(riot.dvs)){
    est <- out[[j]]
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    
    #Save parameters for plotting
    placebo.nb.plot.data[j + length(riot.dvs)*(i-1),3:5] <- c(coef, lower, upper)
  }
  rm(temp.subset)
}

#Warnings can be ignored: indicates that counts are not integers. 
#This is result of matching riots back to 1961 district boundaries. 
#Results are virtually identical when rounding counts to integers.



####################
#Generate Figure A6#
####################

#Select data for plot
plot.data = placebo.nb.plot.data[placebo.nb.plot.data$DV %in% c("Riot Count", "Any Riot"), ]

#Plot labels
y.scale <- list(y=list(at=1:3, labels=paste(1:3,"%",sep=""), alternating=F))
y.label <- "Bandwidth"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,3.5)

#Size on page
width <- 6
height <- 5

#File name
plot.temp <- plot.data
name <- "FigureA6"
file.name <- paste("./output/figures/",name,".pdf", sep="")

x.limits <- max(abs(plot.temp[,4:5])) * c(-1.05, 1.05)

pdf(file.name, width=width, height=height)
dot.plot <- Dotplot(BW ~ Cbind(Beta, lower, upper) | DV, data=plot.temp, strip.blank=T, 
                    col=1,layout=c(1,2), par.settings=my.theme, cex=1.1, scales=y.scale, 
                    ylab=y.label, xlab=x.label, xlim=x.limits, ylim=y.limits,
                    panel = function(...){
                      panel.Dotplot(...)
                      panel.abline(v=0, lty=2, col="gray50")})
print(dot.plot)
dev.off()

#Print table used for chart
cat("\n")
print("Figure A6")
print(plot.temp)
cat('\n')