##############
##############
##Figure D11##
##############
##############

################################
#INC against non-ethnic parties#
################################
#Saturated covariates######
###########################
#Clustered Standard Errors#
###########################

#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC3_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC3_iv"
#Covariate
Cov <- paste(c("saturated3"), collapse="+")

#Generate plot data table
nonethnic.iv.plot.data <- data.frame(matrix(NA, nrow=3*length(log.riot.dvs), ncol=7))
names(nonethnic.iv.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "N", 'p')
nonethnic.iv.plot.data$DV <- rep(log.riot.dv.names, 3)
nonethnic.iv.plot.data$BW <- rep(1:3, each=length(log.riot.dvs))

#Estimates for 3,2,1% bandwidths
for (i in 1:3){
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  rm(temp.data); gc()
  
  out <- Map(function(y,w,x,z) ivreg(as.formula(paste(y,"~",paste(x,w,sep="+"),"|",paste(z,w,sep="+"))),data=temp.subset),log.riot.dvs,Cov,IV_end,IV_exo)
  
  for (j in 1:length(log.riot.dvs)){
    est <- out[[j]]
    #est.cl <- bs.cluster(est, "DISTRICT_ID_61", k=1000)
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    N <- length(est$residuals)
    p <- est.cl[2,4]
    
    nonethnic.iv.plot.data[j + length(out)*(i-1),3:7] <- c(coef, lower, upper, N, p)
    #nonethnic.iv.plot.data[j + length(out)*(i-1),3:5] <- est.cl[2,1:3]			
  }
  rm(temp.subset)
}


############################
#INC against ethnic parties#
############################
#Saturated covariates######
###########################
#Clustered Standard Errors#
###########################

#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC2_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC2_iv"
#Covariate
Cov <- paste(c("saturated2"), collapse="+")

#Generate plot data table
ethnic.iv.plot.data <- data.frame(matrix(NA, nrow=3*length(log.riot.dvs), ncol=7))
names(ethnic.iv.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "N", 'p')
ethnic.iv.plot.data$DV <- rep(log.riot.dv.names, 3)
ethnic.iv.plot.data$BW <- rep(1:3, each=length(log.riot.dvs))

#Estimates for 3,2,1% bandwidths
for (i in 1:3){
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  rm(temp.data); gc()
  
  out <- Map(function(y,w,x,z) ivreg(as.formula(paste(y,"~",paste(x,w,sep="+"),"|",paste(z,w,sep="+"))),data=temp.subset),log.riot.dvs,Cov,IV_end,IV_exo)
  
  for (j in 1:length(log.riot.dvs)){
    est <- out[[j]]
    #est.cl <- bs.cluster(est, "DISTRICT_ID_61", k=1000)
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    N <- length(est$residuals)
    p <- est.cl[2,4]
    
    ethnic.iv.plot.data[j + length(out)*(i-1),3:7] <- c(coef, lower, upper, N, p)
    #ethnic.iv.plot.data[j + length(out)*(i-1),3:5] <- est.cl[2,1:3]			
  }
  rm(temp.subset)
}


#####################
#Generate Figure D11#
#####################

ethnic.iv.plot.data$vs = 2
nonethnic.iv.plot.data$vs = 1

data.for.plots = rbind(nonethnic.iv.plot.data, ethnic.iv.plot.data)
data.for.plots <- data.for.plots[data.for.plots$BW==1,]

#Plot labels
y.scale <- list(y=list(at=1:2, labels=c("All Other Parties", "Ethno-religious Parties"), alternating=F))
y.label <- "INC's Opponent in Close Elections"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,2.5)

#Size on page
width <- 6
height <- 6

plot.temp.1 = data.for.plots[data.for.plots$DV!="Pr(Any Riot)",]
plot.temp.2 = data.for.plots[data.for.plots$DV=="Pr(Any Riot)",]

name <- "FigureD11"
file.name <- paste("./output/figures/",name,".pdf", sep="")


pdf(file.name, width=width, height=height)
x.limits.1 <- max(abs(plot.temp.1[,4:5])) * c(-1.05, 1.05)

dot.plot.1 <- Dotplot(vs ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.1, strip.blank=T, col=1, layout = c(1,3), par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.1, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})

x.limits.2 <- max(abs(plot.temp.2[,4:5])) * c(-1.05, 1.05)

dot.plot.2 <- Dotplot(vs ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.2, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.2, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})	

dot.plot = c(dot.plot.2, dot.plot.1, layout=c(1,4))	
dot.plot = update(dot.plot, between=list(y=c(0,-1.8,-1.8)), scales=list(x=list(at=list(NA, NA, NULL, NULL))), xlab= x.label, ylab=y.label)
print(dot.plot)
dev.off()	


#Print table used for chart
cat("\n")
print("Figure D11")
print(data.for.plots)
cat('\n')