##############
##############
##Figure D13##
##############
##############

###########
#Load data#
###########
data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

#Create indicator for above median ENP
m = median(data$ENP, na.rm=T)
data$high_enp = NA
data$high_enp[!is.na(data$ENP)] = data$ENP[!is.na(data$ENP)] >= m

#Label subsets of the data
##########################
condition <- c("high_enp", "muslim_high")
condition.name <- c("High Party Fractionalization", "High Muslim Pop.")

#Set variable names for analysis
################################
#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Covariate
Cov <- paste(c("saturated"), collapse="+")


#Generate plot data
###################
het.nb.plot.data <- data.frame(matrix(NA, nrow=2*length(condition)*length(riot.dvs), ncol=8))
names(het.nb.plot.data) <- c("DV", "Cond", "Value", "N", "Beta", "lower", "upper", 'p')
het.nb.plot.data$DV <- riot.dv.names 
het.nb.plot.data$Cond <- rep(condition.name, each=length(riot.dvs)*2)
het.nb.plot.data$Value <- rep(c("No","Yes"), each=length(riot.dvs))

#Loop over conditions
#####################
for (i in 1:length(condition)){	
  for (j in 0:1){
    index <- which(data[,condition[i]]==j)
    temp.subset <- data[index,]
    
    #Estimate negative binomial for count outcomes, probit for binary outcomes
    out <- Map(function(y,w,z) 
      if (length(unique(na.omit(temp.subset[,y])))==2){
        glm(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset, family=binomial(link="probit"))	
      }
      else {
        glm.nb(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset)
      }, riot.dvs,Cov,IV_exo)
    
    for (k in 1:length(riot.dvs)){
      est <- out[[k]]
      est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
      coef <- est.cl[2,1]
      se <- est.cl[2,2]
      upper <- coef + 1.96*se
      lower <- coef - 1.96*se
      p <- est.cl[2,4]
      
      plot.index <- k + length(riot.dvs)*j + 2*length(riot.dvs)*(i-1)
      het.nb.plot.data[plot.index,4:8] <- c(length(est$residuals), coef, lower, upper, p)
    }
  }
}


#####################
#Generate Figure D13#
#####################

plot.temp = het.nb.plot.data
plot.temp$Value[plot.temp $Value=="No"] = 1
plot.temp$Value[plot.temp$Value=="Yes"] = 2

plot.temp.1 = plot.temp[plot.temp$DV %in% c("Riot Count"),]
plot.temp.2 = plot.temp[plot.temp$DV %in% c("Any Riot"),]


#Plot labels
y.scale <- list(y=list(at=2:1, labels= c("YES", "NO"), alternating=F), x=list(alternating=F))
y.label <- "Condition"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,2.5)

#X limits
x.limits.1 <- max(abs(plot.temp.1[,6:7])) * c(-1.05, 1.05)
x.limits.2 <- max(abs(plot.temp.2[,6:7])) * c(-1.05, 1.05)

#Size on page
width <- 6
height <- 6

#File name
name <- "FigureD13"
file.name <- paste("./output/figures/",name,".pdf", sep="")

pdf(file.name, width=width, height=height)
dot.plot.1 <- Dotplot(Value ~ Cbind(Beta, lower, upper) | Cond + DV, data= plot.temp.1, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale=y.scale,  ylab=y.label, xlab=x.label, xlim=x.limits.1, ylim=y.limits,
                      panel = function(subscripts,...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")
                        #panel.text(2,.75,labels=paste("N = ",plot.temp.1$N[subscripts]), cex=.75)
                      })

dot.plot.2 <- Dotplot(Value ~ Cbind(Beta, lower, upper) | Cond + DV, data= plot.temp.2, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale=y.scale,  ylab=y.label, xlab=x.label, xlim=x.limits.2, ylim=y.limits,
                      panel = function(subscripts,...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")
                        #panel.text(.5,.75,labels=paste("N = ",plot.temp.2$N[subscripts]), cex=.75)
                      })

dot.plot = c(dot.plot.2, dot.plot.1)	
dot.plot$index.cond = list(c(1,2), c(1,2))
dot.plot$perm.cond= 1:2
dot.plot$condlevels = list(Cond = rev(condition.name), DV = c("Any Riot", "Riot Count"))
print(dot.plot)

dev.off()	


#Print table used for chart
cat("\n")
print("Figure D13")
print(het.nb.plot.data)
cat('\n')