#############
#############
##FIGURE D2##
#############
#############

###########
#Load Data#
###########

barplot.data <- read.csv("./data/muslimVoteshareByParty.csv", as.is=T)

#Create legend labels
parties = unique(barplot.data[, c('party', 'party2')])
parties = parties[order(parties$party2),]

party.id = parties$party2
party.names = parties$party

#Make party into a factor
barplot.data$party2 = as.factor(barplot.data$party2)


####################
#Generate Figure D2#
####################

file.name = './output/figures/FigureD2.pdf'

pdf(file.name, height = 8.5, width=11)

survey.plot = ggplot(barplot.data, aes(x=party2, y=muslim.vs, fill=party2)) +
  geom_bar(position=position_dodge(width=0.9), stat='identity') +
  facet_grid(. ~ year + survey.no, scale="free_x", space="free")

legend.labels = paste("(",party.id,") ", party.names, sep="")

print(survey.plot + theme_bw()+ theme(axis.text.x = element_text(angle = 90, hjust=1), panel.grid.minor=element_blank(), panel.grid.major=element_blank()) + scale_y_continuous(name="Proportion of Respondents") + scale_x_discrete(name="Parties") + scale_fill_grey(name="Parties", breaks=party.id, labels=legend.labels, start = 0, end = .9) )

dev.off()