#############
#############
##FIGURE D5##
#############
#############

######################################
#Reduced form w/ saturated covariates#
######################################


#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("saturated"), collapse="+")

#Generate plot data table
mle.plot.data <- data.frame(matrix(NA, nrow=3*length(riot.dvs), ncol=6))
names(mle.plot.data) <- c("DV", "BW", "Beta", "lower", "upper", "N")
mle.plot.data$DV <- rep(riot.dv.names, 3)
mle.plot.data$BW <- rep(1:3, each=length(riot.dvs))

#Estimate across bandwidths
for (i in 1:3){
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  rm(temp.data); gc()
  
  #Estimate negative binomial for counts; probit for binary indicator
  out <- Map(function(y,w,z) 
    if (length(unique(na.omit(temp.subset[,y])))==2){
      glm(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset, family=binomial(link="probit"))	
    }
    else {
      glm.nb(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset)
    }, riot.dvs,Cov,IV_exo)
  
  #Obtain clustered standard errors
  for (j in 1:length(riot.dvs)){
    est <- out[[j]]
    #est.cl <- bs.cluster(est, "DISTRICT_ID_61", k=1000)
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    
    mle.plot.data[j + length(out)*(i-1),3:5] <- c(coef, lower, upper)
    #mle.plot.data[j + length(out)*(i-1),3:5] <- est.cl[2,1:3]
  }
  rm(temp.subset)
}

##################################
#Reduced form w/ linear covariate#
##################################


#Set variable names for analysis
################################

#Endogenous treatment variable
IV_end <- "rd_INC_seatprop"
#Exogenous treatment variable
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("rd_INC_closeprop"), collapse="+")

#Generate plot data table
mle.plot.data.l <- data.frame(matrix(NA, nrow=3*length(riot.dvs), ncol=6))
names(mle.plot.data.l) <- c("DV", "BW", "Beta", "lower", "upper", "N")
mle.plot.data.l$DV <- rep(riot.dv.names, 3)
mle.plot.data.l$BW <- rep(1:3, each=length(riot.dvs))

#Estimate across bandwidths
for (i in 1:3){
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  rm(temp.data); gc()
  
  #Estimate negative binomial for counts; probit for binary indicator
  out <- Map(function(y,w,z) 
    if (length(unique(na.omit(temp.subset[,y])))==2){
      glm(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset, family=binomial(link="probit"))	
    }
    else {
      glm.nb(as.formula(paste(y,"~",paste(z,w,sep="+"))),data=temp.subset)
    }, riot.dvs,Cov,IV_exo)
  
  #Obtain clustered standard errors
  for (j in 1:length(riot.dvs)){
    est <- out[[j]]
    #est.cl <- bs.cluster(est, "DISTRICT_ID_61", k=1000)
    est.cl <- coeftest.cluster(temp.subset, est, cluster1="DISTRICT_ID_61")
    coef <- est.cl[2,1]
    se <- est.cl[2,2]
    upper <- coef + 1.96*se
    lower <- coef - 1.96*se
    
    mle.plot.data.l[j + length(out)*(i-1),3:5] <- c(coef, lower, upper)
    #mle.plot.data[j + length(out)*(i-1),3:5] <- est.cl[2,1:3]
  }
  rm(temp.subset)
}


####################
#Generate Figure D5#
####################

#Prepare plot data
mle.plot.data$cov = 2
mle.plot.data.l$cov = 1

#Combine data for plots
data.for.plots.rf <- rbind(mle.plot.data, mle.plot.data.l)

#Select bandwidth
data.for.plots.rf <- data.for.plots.rf[data.for.plots.rf$BW==1,]

#Plot labels
y.scale <- list(y=list(at=2:1, labels=c("Saturated Control", "Linear Control"), alternating=F))
y.label <- "Model Specification"
x.label <- expression(paste(hat(beta),": Effect of Congress Seatshare"))
y.limits <- c(.5,2.5)

#Size on page
width <- 6
height <- 6

#Separate scales
plot.temp.1 = data.for.plots.rf[data.for.plots.rf$DV!="Any Riot",]
plot.temp.2 = data.for.plots.rf[data.for.plots.rf$DV=="Any Riot",]

#File name
name <- "FigureD5"
file.name <- paste("./output/figures/",name,".pdf", sep="")

pdf(file.name, width=width, height=height)
x.limits.1 <- max(abs(plot.temp.1[,4:5])) * c(-1.05, 1.05)

dot.plot.1 <- Dotplot(cov ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.1, strip.blank=T, col=1, layout = c(1,3), par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.1, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})

x.limits.2 <- max(abs(plot.temp.2[,4:5])) * c(-1.05, 1.05)

dot.plot.2 <- Dotplot(cov ~ Cbind(Beta, lower, upper) | DV, data=plot.temp.2, strip.blank=T, col=1, par.settings=my.theme, cex=1.1, scale = y.scale, ylab=NULL, xlab=NULL, xlim=x.limits.2, ylim=y.limits,
                      panel = function(...){
                        panel.Dotplot(...)
                        panel.abline(v=0, lty=2, col="gray50")})	

dot.plot = c(dot.plot.2, dot.plot.1, layout=c(1,4))	
dot.plot = update(dot.plot, between=list(y=c(0,-1.8,-1.8)), scales=list(x=list(at=list(NA, NA, NULL, NULL))), xlab= x.label, ylab=y.label)
print(dot.plot)
dev.off()


#Print table used for chart
cat("\n")
print("Figure D5")
print(data.for.plots.rf)
cat('\n')