###################
###################
##Table A1:
###################
###################

###########
#Load data#
###########
data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

#Number of INC close elections
close = sum(data$rd_INC_closenum)

#INC wins in close elections
wins = sum(data$rd_INC_ivnum)

#INC losses in close elections
losses = close - wins

#Chi-square Test
################
#Test if observed wins/losses differ from expected probability if each election is decided at random
test.table = rbind(wins, losses)
test = chisq.test(test.table, p = c(.5,.5))

#Chi-square test statistic, and p value
statistic = sprintf("%1.2f", test$statistic)
p.value = sprintf("%1.2f", test$p.value)

#Prepare LaTeX table
####################
subtext = paste("$\\chi^{2}_{1}=", statistic,",~ P=",p.value,"$", sep="")

#Win and loss proportions
win.prop = sprintf("%1.1f", wins/close*100)
lose.prop = sprintf("%1.1f", losses/close*100)
win.par = paste("(",wins,")", sep="")
lose.par = paste("(",losses,")", sep="")

#Make Table A1
chisq.table = data.frame(cbind(c(lose.prop, lose.par), c(win.prop,win.par)))
names(chisq.table) = c("Losses", "Wins")
rownames(chisq.table) = c("Percent", "Number")

file.name = "./output/tables/TableA1.tex"

if (make.latex.tables){
latex(chisq.table,caption="$\\chi^{2}$ Test of Outcomes in Close Elections", 
      label="table:chisq-test", ctable=T, title="Observed", center='center', 
      colnamesTexCmd = c("", "bfseries","bfseries"), insert.bottom = subtext, 
      file=file.name)
} else {print("TABLE A1:"); print(chisq.table)}
