###################
###################
##Table A2:
###################
###################

# Function to make pretty correlation matrix
corstarsl <- function(x, type = 'pearson'){ 
  require(Hmisc) 
  x <- as.matrix(x) 
  x.corr = rcorr(x, type = type)
  R <- x.corr$r 
  p <- x.corr$P 
  
  ## define notions for significance levels; spacing is important.
  #mystars <- ifelse(p < .001, "***", ifelse(p < .01, "** ", ifelse(p < .05, "* ", " ")))
  
  ## trunctuate the matrix that holds the correlations to two decimal
  R <- format(round(cbind(rep(-1.11, ncol(x)), R), 2))[,-1] 
  
  ## build a new matrix that includes the correlations with their apropriate stars 
  Rnew <- R
  #matrix(paste(R, mystars, sep=""), ncol=ncol(x)) 
  diag(Rnew) <- paste(diag(R), " ", sep="") 
  rownames(Rnew) <- colnames(x) 
  colnames(Rnew) <- paste(colnames(x), "", sep="") 
  
  ## remove upper triangle
  Rnew <- as.matrix(Rnew)
  Rnew[upper.tri(Rnew, diag = TRUE)] <- ""
  Rnew <- as.data.frame(Rnew) 
  
  ## remove last column and return the matrix (which is now a data frame)
  Rnew <- cbind(Rnew[1:length(Rnew)-1])
  return(Rnew) 
}


###########
#Load data#
###########

data <- read.csv("./data/analysisPanelBW1.csv", as.is=T)

#Create variables for proportion of elections closely contested by INC over previous three elections
panel.data = pdata.frame(data, index = c('DISTRICT_ID_61', 'election_cycle'))
panel.data$l1.rd_INC_closeprop = lag(panel.data$rd_INC_closeprop, k = 1)
panel.data$l2.rd_INC_closeprop = lag(panel.data$rd_INC_closeprop, k = 2)
panel.data$l3.rd_INC_closeprop = lag(panel.data$rd_INC_closeprop, k = 3)

#Subset data for correlation matrix
corr.data = panel.data[,c('rd_INC_closeprop', 'l1.rd_INC_closeprop', 'l2.rd_INC_closeprop', 'l3.rd_INC_closeprop')]

#Get N for each
apply(corr.data, 2, function(x) sum(!is.na(x)))

#Add LaTeX friendly column names
names(corr.data) = c('$(T)$', '$(T - 1)$', '$(T - 2)$', '$(T - 3)$')

###################
#Generate Table A2#
###################

cor.matrix = corstarsl(corr.data, type = 'pearson')

file.name = "./output/tables/TableA2.tex"

if (make.latex.tables){
  latex(cor.matrix, caption = "Correlation of Close Elections over Time", 
        landscape=F, ctable=T, file=file.name, title="", 
        label="table:corrtime", insert.bottom = "Pearson correlation coefficients. N is 2556 for $(T - 1)$, 2246 for $(T - 2)$, and 1939 for $(T- 3)$.")
} else {print("TABLE A2:"); print(cor.matrix)}
