###################
###################
##Table D2: F-Tests for First Stage Regression
###################
###################

#Define variables
#################

#Endogenous treatment
IV_end <- "rd_INC_seatprop"
#Exogenous treatment
IV_exo <- "rd_INC_iv"
#Control
Cov <- paste(c("saturated"), collapse="+")


####################################
#Obtain estimates for 1% bandwidths#
####################################

#Generate plot data table
f.stats <- data.frame(matrix(NA, nrow=1, ncol=2))
names(f.stats) <- c("F-Statistic", "$p$")
rownames(f.stats)<- paste(1,"\\%",sep="")

for (i in 1){
  #Load data
  file.path <- paste("./data/analysisPanelBW",i,".csv", sep="")
  temp.data <- read.csv(file.path)
  temp.subset <- temp.data
  rm(temp.data); gc()
  
  #Generate estimates
  out <- Map(function(w,x,z) lm(as.formula(paste(x,"~",paste(z,w,sep="+"))),data=temp.subset),Cov,IV_end,IV_exo)[[1]]
  
  #Obtain cluster robust covariance matrix
  vcov.cl <- coeftest.cluster(temp.subset, out, "DISTRICT_ID_61", vcov=T)[[2]]
  
  #Calculate F-test using cluster robust covariance matrix
  test <- linearHypothesis(out, IV_exo, vcov.=vcov.cl)
  f.stat <- sprintf("%1.2f",test[2,3:4], digits=digs)
  
  #Save to table
  f.stats[i,1:2] <- f.stat
}

###################
#Generate Table D2#
###################


file.name = "./output/tables/TableD2.tex"

if (make.latex.tables){
  latex(f.stats,caption="First Stage F-Test", label="table:ftests", ctable=T, title="Bandwidth", center='center', file=file.name)
} else {print("TABLE D2:"); print(f.stats)}


