###################
###################
##Table D3:
###################
###################

##############################################
#Function to make pretty correlation matrices#
##############################################

corstarsl <- function(x, type = 'pearson'){ 
  require(Hmisc) 
  x <- as.matrix(x) 
  x.corr = rcorr(x, type = type)
  R <- x.corr$r 
  p <- x.corr$P 
  
  ## define notions for significance levels; spacing is important.
  #mystars <- ifelse(p < .001, "***", ifelse(p < .01, "** ", ifelse(p < .05, "* ", " ")))
  
  ## trunctuate the matrix that holds the correlations to two decimal
  R <- format(round(cbind(rep(-1.11, ncol(x)), R), 2))[,-1] 
  
  ## build a new matrix that includes the correlations with their apropriate stars 
  Rnew <- R
  #matrix(paste(R, mystars, sep=""), ncol=ncol(x)) 
  diag(Rnew) <- paste(diag(R), " ", sep="") 
  rownames(Rnew) <- colnames(x) 
  colnames(Rnew) <- paste(colnames(x), "", sep="") 
  
  ## remove upper triangle
  Rnew <- as.matrix(Rnew)
  Rnew[upper.tri(Rnew, diag = TRUE)] <- ""
  Rnew <- as.data.frame(Rnew) 
  
  ## remove last column and return the matrix (which is now a data frame)
  Rnew <- cbind(Rnew[1:length(Rnew)-1])
  return(Rnew) 
}

###########
#Load data#
###########

#Get attributes from balance data
elections = read.csv("./data/closeElectionBalanceData.csv", as.is=T)
district.attributes  = unique(elections[,c('year', 'DISTRICT_ID_61', 'pct_muslim', 'pct_urban', 'pop_density')])
names(district.attributes)[1] = 'election_year'

#Load district data
data <- read.csv("./data/analysisPanelBW1.csv")

#Merge
data.merged = merge(data, district.attributes, by= c('DISTRICT_ID_61', 'election_year'))
data.merged$any_INC_close = 1*(data.merged$rd_INC_closenum > 0)

###################
#Generate Table D2#
###################

#Columns for matrix
corr.data = data.merged[,c('rd_INC_closeprop', 'any_INC_close', 'pct_muslim', 'pct_urban', 'pop_density')]

#Variable names
vars = c("Prop. Close Elections", "Any Close Election", "\\% Muslim", "\\% Urban", "Population Density")
names(corr.data) = vars

#Create correlation matrix
#We use rank correlation, since relations may not be linear.
cor.matrix = corstarsl(corr.data, type = 'spearman')

file.name = "./output/tables/TableD3.tex"

if (make.latex.tables){
  latex(cor.matrix, caption = "Correlates of Close Elections", landscape=F, ctable=T, 
        file=file.name, title="", label="tab:extvalid", 
        insert.bottom = "Spearman rank correlation coefficients. N is 2787 for \\% Muslim and Urban and 2436 for Population Density.")
} else {print("TABLE D3:"); print(cor.matrix)}






