### Replication code for "Testing the Accuracy of Regression Discontinuity Analysis 
### Using Experimental Benchmarks" by Donald P. Green, Terence Y. Leong, Holger L. Kern,
### Alan S. Gerber, and Christopher W. Larimer

# Function to estimate local average treatment effects using local linear regression with
# triangular (edge) kernel

# using R 2.9.0


edge <- function(Y,X,c,h)   {

    require(sandwich)

    temp <- (X - c) / h
    kern <- as.numeric(abs(temp) <= 1) * (1 - abs(temp))

    above <- X >= c
    X.cen <- X - c

    X.cenAbove <- X.cen * above
    sel <- kern > 0


    wls.pool <- lm(Y ~ above + X.cen + X.cenAbove, weights = kern, subset = sel)
    summary(wls.pool)
    
    theta <- summary(wls.pool)$coeff[2,1]
    se <- sqrt(diag(vcovHC(wls.pool, type = "HC3")))[2]
    N.unweighted <- length(wls.pool$weights)
    N.weighted <- sum(wls.pool$weights)
    N.above <- table(above[sel])[2]
    N.below <- table(above[sel])[1]
	df <- wls.pool$df.residual

    return(list(model = wls.pool, theta = theta, se = se, df = df, N.unweighted = N.unweighted,
    N.weighted = N.weighted, N.above = N.above, N.below = N.below,
    coeff = summary(wls.pool)$coeff,
    robust.se = sqrt(diag(vcovHC(wls.pool, type = "HC3")))))

}



edge.cluster <- function(Y,X,c,h,cluster)   {
  source("scripts/functions/cluster2.R")
  require(sandwich)
  
  temp <- (X - c) / h
  kern <- as.numeric(abs(temp) <= 1) * (1 - abs(temp))
  
  above <- X >= c
  X.cen <- X - c
  
  X.cenAbove <- X.cen * above
  sel <- kern > 0
  
  d = data.frame(Y = Y[sel], above = above[sel], X.cen = X.cen[sel], X.cenAbove = X.cenAbove[sel], kern = kern[sel], cluster = cluster[sel])
  wls.pool <- lm(Y ~ above + X.cen + X.cenAbove, weights = kern, data = d)
  summary(wls.pool)
  coef = coeftest.cluster(d, wls.pool, 'cluster')
  
  theta <- summary(wls.pool)$coeff[2,1]
  se <- coef[2,2]
  N.unweighted <- length(wls.pool$weights)
  N.weighted <- sum(wls.pool$weights)
  N.above <- table(above[sel])[2]
  N.below <- table(above[sel])[1]
  df <- wls.pool$df.residual
  
  return(list(model = wls.pool, theta = theta, se = se, df = df, N.unweighted = N.unweighted,
              N.weighted = N.weighted, N.above = N.above, N.below = N.below,
              coeff = summary(wls.pool)$coeff,
              robust.se = sqrt(diag(vcovHC(wls.pool, type = "HC3")))))
  
}
