### Replication code for "Testing the Accuracy of Regression Discontinuity Analysis 
### Using Experimental Benchmarks" by Donald P. Green, Terence Y. Leong, Holger L. Kern,
### Alan S. Gerber, and Christopher W. Larimer

# Function to estimate the asymptotically optimal bandwidth following Imbens and
# Kalyanaraman (2009)

# using R 2.9.0


optimal.bw <- function(Y,X,c,reg)   {

    # STEP 1
    above <- X >= c
    N <- length(X)
    S2x <- sum((X-mean(X))^2) / (N-1)
    h1 <- 1.84 * sqrt(S2x) * N^(-1/5)

    Nh1.neg <- length(X[X < c & X >= (c-h1)])
    Nh1.pos <- length(X[X >= c & X <= (h1+c)])

    Yh1.neg <- sum(Y[X < c & X >= (c-h1)]) / Nh1.neg
    Yh1.pos <- sum(Y[X >= c & X <= (h1+c)]) / Nh1.pos

    fhatx <- (Nh1.neg + Nh1.pos) / (N*h1*2)

    fhatx.temp1 <- sum((Y[X < c & X >= (c-h1)] - Yh1.neg)^2)
    fhatx.temp2 <- sum((Y[X >= c & X < (h1+c)] - Yh1.pos)^2)

    sigmahat2 <- (fhatx.temp1 + fhatx.temp2) / (Nh1.neg + Nh1.pos)


    # STEP 2

    medianX.pos <- median(X[X >= c])
    medianX.neg <- median(X[X < c])

    keep <- !(X < medianX.neg | X > medianX.pos)

    X.cen <- X - c
    X.cen2 <- X.cen^2
    X.cen3 <- X.cen^3

    lm.out <- lm(Y ~ above + X.cen + X.cen2 + X.cen3, subset = keep)
    summary(lm.out)

    mhat3 <- summary(lm.out)$coef[5,1] * 6


    N.pos <- sum(above)
    N.neg <- length(above) - sum(above)

    h2.pos <- (sigmahat2 / (fhatx * max(mhat3^2, .01)))^(1/7) * 3.56 * N.pos^(-1/7)
    h2.neg <- (sigmahat2 / (fhatx * max(mhat3^2, .01)))^(1/7) * 3.56 * N.neg^(-1/7)


    Yhat.pos <- Y[X >= c & X <= (h2.pos+c)]
    Xhat.pos <- X[X >= c & X <= (h2.pos+c)]

    Yhat.neg <- Y[X < c & X >= (c-h2.neg)]
    Xhat.neg <- X[X < c & X >= (c-h2.neg)]

    N2.pos <- length(Xhat.pos)
    N2.neg <- length(Xhat.neg)

    Xhat.pos.cen <- Xhat.pos - c
    Xhat.pos.cen2 <- Xhat.pos.cen^2

    Xhat.neg.cen <- Xhat.neg - c
    Xhat.neg.cen2 <- Xhat.neg.cen^2


    lm.out <- lm(Yhat.pos ~ Xhat.pos.cen + Xhat.pos.cen2)
    summary(lm.out)
    mhat2.pos <- summary(lm.out)$coef[3,1] * 2

    lm.out <- lm(Yhat.neg ~ Xhat.neg.cen + Xhat.neg.cen2)
    summary(lm.out)
    mhat2.neg <- summary(lm.out)$coef[3,1] * 2


    # STEP 3

    rhat.pos <- (720 * sigmahat2) / (N2.pos * h2.pos^4) # NOT identical to IK paper
    rhat.neg <- (720 * sigmahat2) / (N2.neg * h2.neg^4) # NOT identical to IK paper

    if(reg == F)    { rhat.pos <- 0; rhat.neg <- 0 }    # turn off regularization


    hhat.opt <- ((2 * sigmahat2) /
                (fhatx * ((mhat2.pos - mhat2.neg)^2 + (rhat.pos + rhat.neg))))^(1/5) *
                3.4375 * N^(-1/5)


    return(hhat.opt)

 }
