bs.cluster <- function(model,cluster.var,k=500,alpha=.05, return.bs=FALSE, seed = NULL){
	call <- as.character(model$call)
	terms <- as.character(model$terms)
	estimator <- call[1]
	
	if (estimator == 'ivreg'){formula <- paste(terms[1], gsub("~", "|",terms[2]))} else {formula <- paste(terms[2],terms[1],terms[3],sep=" ")}
	data <- call[3]
	varlist <- names(model$model)

	temp.data <- subset(eval(parse(text=data)), select=c(varlist,cluster.var))
	#inc.obs <- complete.cases(temp.data)
	
	clusters <- unique(temp.data[,cluster.var])
	
	cl.index <- vector('list', length(clusters))
	names(cl.index) <- clusters
	
	for (j in 1:length(clusters)){
		cl.index[[j]] <- which(temp.data[,cluster.var]==clusters[j])
	}
	
	bs.results <- matrix(NA, nrow=k, ncol=(model$rank))
	
	if (!is.null(seed)){
	  set.seed(seed)
	}
	
	for (i in 1:k){
		cluster.sample <- sample(clusters, replace=T)
		bs.sample.index <- unlist(cl.index[c(as.character(cluster.sample))])
		bs.data <- temp.data[bs.sample.index,]
		
		est.syntax <- paste(estimator,"(",formula,",data=bs.data)", sep="")
		est <- eval(parse(text=est.syntax))
		
		#In case bootstrap causes variable to drop out, we match coefficients by variable name
		var.index <- which(names(model$coef) %in% names(est$coef))
		bs.results[i, var.index] <- est$coef
		
			if (i %% 10 == 0){
			cat(i)
			}
			else {cat('.')}
		}
	
	ci.table <- t(apply(bs.results, 2, function(x) quantile(x, probs=c(alpha/2,1 - alpha/2), na.rm=T)))
	above.0 <- apply(bs.results, 2, function(x) sum(x>0)/length(x)) 
	below.0 <- apply(bs.results, 2, function(x) sum(x<0)/length(x))
	p <- rep(NA,length(model$coef))
	p[model$coef<0] <- above.0[model$coef<0]
	p[model$coef>0] <- below.0[model$coef>0]
	
	
	
	if (return.bs==FALSE){
	return(cbind(Estimate=model$coef,ci.table,p))}
	
	if (return.bs==TRUE) {return(list(cbind(Estimate=model$coef,ci.table,p), bs.results))}
}

